from uuid import uuid4

import pytest
from orchestrator.db import (
    ProcessStepTable,
    ProcessSubscriptionTable,
    ProcessTable,
    db,
)
from orchestrator.workflow import ProcessStatus


@pytest.fixture()
def create_process(faker, nokia_router_subscription_factory):
    process_id = uuid4()
    process = ProcessTable(process_id=process_id, workflow_name=faker.sentence(), last_status=ProcessStatus.SUSPENDED)
    subscription = nokia_router_subscription_factory()
    process_subscription = ProcessSubscriptionTable(process_id=process_id, subscription_id=subscription)

    db.session.add(process)
    db.session.add(process_subscription)
    db.session.commit()

    return process_id


def test_callback_results_endpoint(test_client, create_process, faker):
    expected_result = {"id": 1, "output": faker.sentence()}

    step = ProcessStepTable(
        process_id=create_process,
        name="Modify",
        status="suspend",
        state={"subscription_id": uuid4(), "callback_result": expected_result},
    )
    db.session.add(step)
    db.session.commit()

    response = test_client.get(f"/api/v1/processes/steps/{step.step_id}/callback-results")

    assert response.status_code == 200
    assert response.json() == {"callback_results": expected_result}


def test_callback_results_endpoint_with_wrong_step_id(test_client):
    response = test_client.get(f"/api/v1/processes/steps/{uuid4()}/callback-results")

    assert response.status_code == 404
    assert response.json() == {"detail": "Callback result not found."}
